@@ -42,7 +42,7 @@ def repeat_audio(cmnd):
     output_name = "repeated.wav"
     text_to_file = cmnd[1]
     input_name= cwd +'/'+ text_to_file
-    print "file 1"
+    print ("file 1")
     print(input_name)
 
     repeated_times = 2
